/**************************************************************************
** Copyright (c) 1992 Novell, Inc.  All Rights Reserved.
**
** THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND
** TREATIES.  USE AND REDISTRIBUTION OF THIS WORK IS SUBJECT TO THE
** LICENSE AGREEMENT ACCOMPANYING THE SOFTWARE DEVELOPMENT KIT (SDK)
** THAT CONTAINS THIS WORK.
** 
** Pursuant to the SDK License Agreement, Novell hereby grants to
** Developer a royalty-free, non-exclusive license to include the
** sample code CUSTINFO.CPP and derivative binaries in its product.
** Novell grants to Developer worldwide distribution rights to market,
** distribute or sell the sample code CUSTINFO.CPP and derivative
** binaries as a component of Developer's product(s).  Novell shall
** have no obligations to Developer or Developer's customers with
** respect to this code.
** 
** DISCLAIMER:
** 
** 	Novell, Inc. makes no representations or warranties with respect
** to the contents or use of this code, and specifically disclaims any
** express or implied warranties of merchantability or fitness for any
** particular purpose.  Further, Novell, Inc. reserves the right to revise
** this publication and to make changes to its content, at any time,
** without obligation to notify any person or entity of such revisions or
** changes.
**
** 	Further, Novell, Inc. makes no representations or warranties with
** respect to any software, and specifically disclaims any express or
** implied warranties of merchantability or fitness for any particular
** purpose.  Further, Novell, Inc. reserves the right to make changes to
** any and all parts of the software, at any time, without obligation to
** notify any person or entity of such changes.
**
***************************************************************************
** File Name  :	CUSTINFO.CPP
** Description: This sample code demonstrates how to use the new 
**              connection services calls.
**
** Programmer:  Karl Bunnell
** Date:        02/22/96
*/

#include <stdio.h>
#include <stdlib.h>
#include <nwcalls.h>
#include <nwclxcon.h>
#include <nwfse.h>
#include <ntypes.h>

unsigned _stklen = 8192;

void main()
{
	NWRCODE cCode;
	NWRCODE scanCode = 0;
	NWCONN_HANDLE	connHandle;
	nuint32 scanIt = 0;
	nuint32 connRef;
	NWCCConnInfo	connInfoBuf;
	NWCCConnInfo   connInfoBuf2;
	char 	    	serverName[48];
	nuint8 		majorVersion;
	nuint8		minorVersion;
	nuint8		revision;


	cCode = NWCallsInit(NULL,NULL);
		if(cCode)
			{
			 printf("\nNWCallsInit() returned %04X", cCode);
          exit(1);
			}

	while(scanCode != NWE_NO_MORE_ENTRIES)
		{
		scanCode = NWCCScanConnRefs(
					/* scan iter   */ &scanIt,
					/* conn ref    */ &connRef
					);

		if(scanCode && scanCode != NWE_NO_MORE_ENTRIES)
			{
			 printf("\nNWCCScanConnRefs() returned %04X", scanCode);
			}
					
		cCode = NWCCGetAllConnRefInfo(
					/* conn ref        */ connRef,
					/* conn Ver info   */ NWCC_INFO_VERSION,
					/* conn info buffer*/ &connInfoBuf
					);

		if(cCode)
			{
			 printf("\nNWCCGetAllConnRefInfo() returned %04X", cCode);
          exit(1);
			}

		printf("\n--------------------Connection Reference Information---------------------\n");
	  
		printf("\nServer Name         : %s", connInfoBuf.serverName);
		printf("\nTree Name           : %s", connInfoBuf.treeName);
		printf("\nConnection          : %d", connInfoBuf.connNum);
		printf("\nAuthentication State: %s", 
			(connInfoBuf.authenticationState & NWCC_AUTHENT_STATE_NDS) ? "NDS" : "BIND");
		printf("\nNDS Capable         : %s", 
			(connInfoBuf.NDSState & NWCC_NDS_CAPABLE) ? "Yes" : "No");
		printf("\nLicensed State      : ");

		if(connInfoBuf.licenseState & NWCC_NOT_LICENSED)
					 printf("Not Licensed");

		if(connInfoBuf.licenseState & NWCC_CONNECTION_LICENSED)
					 printf("Connection Licensed");

		if(connInfoBuf.licenseState & NWCC_HANDLE_LICENSED)
					 printf("Handle Licensed");

		printf("\nMax Packet Size     : %d", connInfoBuf.maxPacketSize);
		printf("\nDistance            : %d", connInfoBuf.distance);

		cCode = NWCCOpenConnByRef(
					/* conn ref     */  connRef,
					/* open state   */  NWCC_OPEN_LICENSED,
					/* reserved     */  NWCC_RESERVED,
					/* conn handle  */  &connHandle
					);


		cCode = NWGetFileServerInformation(
				/* Connection handle    */ connHandle,
				/* Server Name          */ serverName,
				/* major version        */ &majorVersion,
				/* minor version        */ &minorVersion,
				/* revision             */ &revision,
				/* max connections      */ NULL,
				/* Max Connections used */ NULL,
				/* Connections in use   */ NULL,
				/* Number of volumes    */ NULL,
				/* SFTLevel             */ NULL,
				/* TTSLevel             */ NULL
				);

		if (cCode)
			{
			printf("NWGetFileServerInformation returned: %04X\n", cCode);
			exit(1);
			}

		
	  printf("\n%s %d.%d %d \n", serverName, majorVersion, minorVersion, revision);

	  cCode = NWCCCloseConn(
					/* conn handle */ connHandle
					);
		if (cCode)
			{
			printf("NWCCCloseConn returned: %04X\n", cCode);
			exit(1);
			}

		cCode = NWCCOpenConnByName (
			/* NWCONN_HANDLE     */		0,
			/* pnstr8            */		connInfoBuf.serverName,
			/* NWCCNameFormat    */		NWCC_NAME_FORMAT_BIND,
			/* NWCCOpenState     */		NWCC_OPEN_UNLICENSED,
			/* NWCCReserved	   */		NWCC_RESERVED,
			/* NWCONN_HANDLE 	   */		&connHandle
			);

		if(cCode)
		{
			printf("\nNWCCOpenConnByName() returned %04X", cCode);
			exit(1);
		}

		cCode = NWCCGetAllConnInfo(
					/* conn Handle   */ connHandle,
					/* conn info ver */ NWCC_INFO_VERSION,
					/* conn info Buf */ &connInfoBuf2
					);

		if(cCode)
		{
			printf("\nNWCCGetAllConnInfo() returned %04X", cCode);
			exit(1);
		}

		printf("\n--------------------Connection Handle Information---------------------\n");

		printf("\nServer Name         : %s", connInfoBuf2.serverName);
		printf("\nTree Name           : %s", connInfoBuf2.treeName);
		printf("\nConnection          : %d", connInfoBuf2.connNum);
		printf("\nAuthentication State: %s", 
			(connInfoBuf2.authenticationState & NWCC_AUTHENT_STATE_NDS) ? "NDS" : "BIND");
		printf("\nNDS Capable         : %s", 
			(connInfoBuf2.NDSState & NWCC_NDS_CAPABLE) ? "Yes" : "No");
		printf("\nLicensed State      : ");

		if(connInfoBuf2.licenseState & NWCC_NOT_LICENSED)
					 printf("Not Licensed");

		if(connInfoBuf2.licenseState & NWCC_CONNECTION_LICENSED)
					 printf("Connection Licensed");

		if(connInfoBuf2.licenseState & NWCC_HANDLE_LICENSED)
					 printf("Handle Licensed");

		printf("\nMax Packet Size     : %d", connInfoBuf2.maxPacketSize);
		printf("\nDistance            : %d", connInfoBuf2.distance);

		cCode = NWCCCloseConn(
						/* conn handle */ connHandle
						);
		if (cCode)
		 {
		 printf("NWCCCloseConn returned: %04X\n", cCode);
		 exit(1);
		 }

		}


}
